@@ -63,7 +63,7 @@ class AthenaClient:
         try:
             payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role})
             r = requests.post(self._ccf_services_host + API_VALIDATE_USER, data=payload, headers=HEADERS,
-                              cookie=dict(sessionId=self._access_token))
+                              cookies=dict(sessionId=self._access_token))
             response = r.json()
             if response[STATUS] == SUCCESS:
                 return response[RESULT]
@@ -84,7 +84,7 @@ class AthenaClient:
         try:
             payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role})
             r = requests.post(self._ccf_services_host + API_GET_ATHENA_DATABASES, data=payload, headers=HEADERS,
-                              cookie=dict(sessionId=self._access_token))
+                              cookies=dict(sessionId=self._access_token))
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
@@ -109,7 +109,7 @@ class AthenaClient:
         try:
             payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role, "schema_name": schema_name})
             r = requests.post(self._ccf_services_host + API_GET_ATHENA_TABLES, data=payload, headers=HEADERS,
-                              cookie=dict(sessionId=self._access_token))
+                              cookies=dict(sessionId=self._access_token))
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
@@ -135,7 +135,7 @@ class AthenaClient:
             payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role, "schema_name": schema_name,
                                   "table_name": table_name, "limit": limit})
             r = requests.post(self._ccf_services_host + API_QUERY_ATHENA_TABLE, data=payload, headers=HEADERS,
-                              cookie=dict(sessionId=self._access_token))
+                              cookies=dict(sessionId=self._access_token))
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
@@ -161,7 +161,7 @@ class AthenaClient:
             payload = json.dumps(
                 {"user_name": self._user_name, "role_id": self._user_role, "query_string": query_string})
             r = requests.post(self._ccf_services_host + API_RUN_QUERY_ON_ATHENA, data=payload, headers=HEADERS,
-                              cookie=dict(sessionId=self._access_token))
+                              cookies=dict(sessionId=self._access_token))
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
